atebounds: Bounding the average treatment effect (ATE)

View source: R/atebounds.R

ateboundsR Documentation

Bounding the average treatment effect (ATE)

Description

Bounds the average treatment effect (ATE) under the unconfoundedness assumption without the overlap condition.

Usage

atebounds(
  Y,
  D,
  X,
  rps,
  Q = 3L,
  studentize = TRUE,
  alpha = 0.05,
  x_discrete = FALSE,
  n_hc = NULL
)

Arguments

Y

n-dimensional vector of binary outcomes

D

n-dimensional vector of binary treatments

X

n by p matrix of covariates

rps

n-dimensional vector of the reference propensity score

Q

bandwidth parameter that determines the maximum number of observations for pooling information (default: Q = 3)

studentize

TRUE if the columns of X are studentized and FALSE if not (default: TRUE)

alpha

(1-alpha) nominal coverage probability for the confidence interval of ATE (default: 0.05)

x_discrete

TRUE if the distribution of X is discrete and FALSE otherwise (default: FALSE)

n_hc

number of hierarchical clusters to discretize non-discrete covariates; relevant only if x_discrete is FALSE. The default choice is n_hc = ceiling(length(Y)/10), so that there are 10 observations in each cluster on average.

Value

An S3 object of type "ATbounds". The object has the following elements.

call

a call in which all of the specified arguments are specified by their full names

type

ATE

cov_prob

Confidence level: 1-alpha

y1_lb

estimate of the lower bound on the average of Y(1), i.e. E[Y(1)]

y1_ub

estimate of the upper bound on the average of Y(1), i.e. E[Y(1)]

y0_lb

estimate of the lower bound on the average of Y(0), i.e. E[Y(0)]

y0_ub

estimate of the upper bound on the average of Y(0), i.e. E[Y(0)]

est_lb

estimate of the lower bound on ATE, i.e. E[Y(1) - Y(0)]

est_ub

estimate of the upper bound on ATE, i.e. E[Y(1) - Y(0)]

est_rps

the point estimate of ATE using the reference propensity score

se_lb

standard error for the estimate of the lower bound on ATE

se_ub

standard error for the estimate of the upper bound on ATE

ci_lb

the lower end point of the confidence interval for ATE

ci_ub

the upper end point of the confidence interval for ATE

References

Sokbae Lee and Martin Weidner. Bounding Treatment Effects by Pooling Limited Information across Observations. Forthcoming at the Journal of Econometrics.

Examples

  Y <- RHC[,"survival"]
  D <- RHC[,"RHC"]
  X <- RHC[,c("age","edu")]
  rps <- rep(mean(D),length(D))
  results_ate <- atebounds(Y, D, X, rps, Q = 3)


ATbounds documentation built on May 8, 2026, 1:06 a.m.