summary.ATbounds: Summary method for ATbounds objects

View source: R/summary.ATbounds.R

summary.ATboundsR Documentation

Summary method for ATbounds objects

Description

Produce a summary for an ATbounds object.

Usage

## S3 method for class 'ATbounds'
summary(object, ...)

Arguments

object

ATbounds object

...

Additional arguments for summary generic

Value

A summary is produced with bounds estimates and confidence intervals. In addition, it has the following elements.

Lower_Bound

lower bound estimate and lower end point of the confidence interval

Upper_Bound

upper bound estimate and upper end point of the confidence interval

References

Sokbae Lee and Martin Weidner. Bounding Treatment Effects by Pooling Limited Information across Observations. Forthcoming at the Journal of Econometrics.

Examples

  Y <- RHC[,"survival"]
  D <- RHC[,"RHC"]
  X <- RHC[,c("age","edu")]
  rps <- rep(mean(D),length(D))
  results_ate <- atebounds(Y, D, X, rps, Q = 3)
  summary(results_ate)


ATbounds documentation built on May 8, 2026, 1:06 a.m.