View source: R/simulation_dgp.R
| simulation_dgp | R Documentation |
Simulates observations from the data-generating process considered in Lee and Weidner
simulation_dgp(n, ps_spec = "overlap", x_discrete = FALSE)
n |
sample size |
ps_spec |
specification of the propensity score: "overlap" or "non-overlap" (default: "overlap") |
x_discrete |
TRUE if the distribution of the covariate is uniform on the grid -3.0, -2.9, ..., 3.0 and FALSE if the distribution of the covariate is uniform on [-3,3] (default: FALSE) |
An S3 object of type "ATbounds". The object has the following elements.
outcome |
n observations of binary outcomes |
treat |
n observations of binary treatments |
covariate |
n observations of a scalar covariate |
ate_oracle |
the sample analog of E[Y(1) - Y(0)] |
att_oracle |
the sample analog of E[D * (Y(1) - Y(0)) | D = 1] |
Sokbae Lee and Martin Weidner. Bounding Treatment Effects by Pooling Limited Information across Observations. Forthcoming at the Journal of Econometrics.
data <- simulation_dgp(100, ps_spec = "overlap")
y <- data$outcome
d <- data$treat
x <- data$covariate
ate <- data$ate_oracle
att <- data$att_oracle
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.