View source: R/summary.ATbounds.R
| summary.ATbounds | R Documentation |
Produce a summary for an ATbounds object.
## S3 method for class 'ATbounds'
summary(object, ...)
object |
ATbounds object |
... |
Additional arguments for summary generic |
A summary is produced with bounds estimates and confidence intervals. In addition, it has the following elements.
Lower_Bound |
lower bound estimate and lower end point of the confidence interval |
Upper_Bound |
upper bound estimate and upper end point of the confidence interval |
Sokbae Lee and Martin Weidner. Bounding Treatment Effects by Pooling Limited Information across Observations. Forthcoming at the Journal of Econometrics.
Y <- RHC[,"survival"]
D <- RHC[,"RHC"]
X <- RHC[,c("age","edu")]
rps <- rep(mean(D),length(D))
results_ate <- atebounds(Y, D, X, rps, Q = 3)
summary(results_ate)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.